@@ -33,7 +33,7 @@ pub fn request(endpoint : &str) -> Result<bytes::Bytes, Error> {
     }
 }
 
-/// Makes a GET request to a give url 
+/// Makes a GET request to a given url 
 /// 
 /// # Example
 /// ```
@@ -56,12 +56,3 @@ pub fn _request(url : &str) -> Result<bytes::Bytes, Error> {
         }
     }
 }
-
-#[cfg(test)]
-mod tests {
-    #[test]
-    fn it_works() {
-        let result = 2 + 2;
-        assert_eq!(result, 4);
-    }
-}
